summaryrefslogtreecommitdiff
path: root/sc/source/ui/inc/pvlaydlg.hxx
diff options
context:
space:
mode:
authorMikhail Voytenko <mav@openoffice.org>2011-01-17 13:20:22 +0100
committerMikhail Voytenko <mav@openoffice.org>2011-01-17 13:20:22 +0100
commitcd42389ad67b403a07a0dda8e2a6e213def49251 (patch)
tree51e19c743788a549502b7c801c64e11142103310 /sc/source/ui/inc/pvlaydlg.hxx
parent3d6a5a98cda10e18dacd96028f2bf0ec0b478988 (diff)
removetooltypes01: #i112600# remove tooltypes from sc
Diffstat (limited to 'sc/source/ui/inc/pvlaydlg.hxx')
-rw-r--r--sc/source/ui/inc/pvlaydlg.hxx26
1 files changed, 13 insertions, 13 deletions
diff --git a/sc/source/ui/inc/pvlaydlg.hxx b/sc/source/ui/inc/pvlaydlg.hxx
index e16c3266510e..45eef2f364fb 100644
--- a/sc/source/ui/inc/pvlaydlg.hxx
+++ b/sc/source/ui/inc/pvlaydlg.hxx
@@ -91,19 +91,19 @@ public:
virtual ~ScDPLayoutDlg();
virtual void SetReference( const ScRange& rRef, ScDocument* pDoc );
- virtual BOOL IsRefInputMode() const { return bRefInputMode; }
+ virtual sal_Bool IsRefInputMode() const { return bRefInputMode; }
virtual void SetActive();
- virtual BOOL Close();
+ virtual sal_Bool Close();
virtual void StateChanged( StateChangedType nStateChange );
void NotifyDoubleClick ( ScDPFieldType eType, size_t nFieldIndex );
PointerStyle NotifyMouseButtonDown( ScDPFieldType eType, size_t nFieldIndex );
void NotifyMouseButtonUp ( const Point& rAt );
PointerStyle NotifyMouseMove ( const Point& rAt );
- void NotifyFieldFocus ( ScDPFieldType eType, BOOL bGotFocus );
+ void NotifyFieldFocus ( ScDPFieldType eType, sal_Bool bGotFocus );
void NotifyMoveField ( ScDPFieldType eToType );
void NotifyRemoveField ( ScDPFieldType eType, size_t nFieldIndex );
- BOOL NotifyMoveSlider ( USHORT nKeyCode ); // return TRUE, if position changed
+ sal_Bool NotifyMoveSlider ( sal_uInt16 nKeyCode ); // return sal_True, if position changed
protected:
virtual void Deactivate();
@@ -159,7 +159,7 @@ private:
ScDPFieldType eDnDFromType;
size_t nDnDFromIndex;
- BOOL bIsDrag;
+ sal_Bool bIsDrag;
::formula::RefEdit* pEditActive;
@@ -185,7 +185,7 @@ private:
ScPivotParam thePivotData;
ScViewData* pViewData;
ScDocument* pDoc;
- BOOL bRefInputMode;
+ sal_Bool bRefInputMode;
private:
ScDPFieldWindow& GetFieldWindow ( ScDPFieldType eType );
@@ -199,8 +199,8 @@ private:
ScDPLabelData* GetLabelData ( SCsCOL nCol, size_t* pPos = NULL );
String GetLabelString ( SCsCOL nCol );
bool IsOrientationAllowed( SCsCOL nCol, ScDPFieldType eType );
- String GetFuncString ( USHORT& rFuncMask, BOOL bIsValue = TRUE );
- BOOL Contains ( ScDPFuncDataVec* pArr, SCsCOL nCol, size_t& nAt );
+ String GetFuncString ( sal_uInt16& rFuncMask, sal_Bool bIsValue = sal_True );
+ sal_Bool Contains ( ScDPFuncDataVec* pArr, SCsCOL nCol, size_t& nAt );
void Remove ( ScDPFuncDataVec* pArr, size_t nAt );
void Insert ( ScDPFuncDataVec* pArr, const ScDPFuncData& rFData, size_t nAt );
@@ -210,14 +210,14 @@ private:
ScDPFieldType eToType, const Point& rAtPos );
void RemoveField ( ScDPFieldType eRemType, size_t nRemIndex );
- BOOL GetPivotArrays ( PivotField* pPageArr,
+ sal_Bool GetPivotArrays ( PivotField* pPageArr,
PivotField* pColArr,
PivotField* pRowArr,
PivotField* pDataArr,
- USHORT& rPageCount,
- USHORT& rColCount,
- USHORT& rRowCount,
- USHORT& rDataCount );
+ sal_uInt16& rPageCount,
+ sal_uInt16& rColCount,
+ sal_uInt16& rRowCount,
+ sal_uInt16& rDataCount );
void UpdateSrcRange();